dj_oydiv.admin package
======================

Submodules
----------

dj_oydiv.admin.override_password_form module
--------------------------------------------

.. automodule:: dj_oydiv.admin.override_password_form
    :members:
    :undoc-members:
    :show-inheritance:

dj_oydiv.admin.vidyoadmin module
--------------------------------

.. automodule:: dj_oydiv.admin.vidyoadmin
    :members:
    :undoc-members:
    :show-inheritance:

dj_oydiv.admin.vidyouser_generic module
---------------------------------------

.. automodule:: dj_oydiv.admin.vidyouser_generic
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: dj_oydiv.admin
    :members:
    :undoc-members:
    :show-inheritance:
